@@ -12,10 +12,18 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
+#include "adder.h"
+#include "alsamixer.h"
+#include "alsasink.h"
+#include "alsasrc.h"
 #include "audioclock.h"
+#include "audioconvert.h"
 #include "audiofilter.h"
+#include "audiorate.h"
+#include "audioresample.h"
 #include "audiosink.h"
 #include "audiosrc.h"
+#include "audiotestsrc.h"
 #include "baseaudiosink.h"
 #include "baseaudiosrc.h"
 #include "basesink.h"
@@ -26,73 +34,23 @@
 #include "bufferlist.h"
 #include "bus.h"
 #include "caps.h"
+#include "capsfilter.h"
 #include "cddabasesrc.h"
+#include "cdparanoiasrc.h"
 #include "childproxy.h"
 #include "clock.h"
-#include "colorbalancechannel.h"
+#include "clockoverlay.h"
 #include "colorbalance.h"
-#include "elementfactory.h"
+#include "colorbalancechannel.h"
+#include "decodebin.h"
+#include "decodebin2.h"
+#include "discoverer.h"
+#include "discovererinfo.h"
 #include "element.h"
+#include "elementfactory.h"
 #include "enums.h"
 #include "error.h"
 #include "event.h"
-#include "filter.h"
-#include "format.h"
-#include "ghostpad.h"
-#include "indexfactory.h"
-#include "index.h"
-#include "interface.h"
-#include "iterator.h"
-#include "message.h"
-#include "mixer.h"
-#include "mixeroptions.h"
-#include "mixertrack.h"
-#include "navigation.h"
-#include "object.h"
-#include "pad.h"
-#include "padtemplate.h"
-#include "parse.h"
-#include "pipeline.h"
-#include "pluginfeature.h"
-#include "plugin.h"
-#include "preset.h"
-#include "propertyprobe.h"
-#include "pushsrc.h"
-#include "query.h"
-#include "registry.h"
-#include "ringbuffer.h"
-#include "segment.h"
-#include "streamvolume.h"
-#include "structure.h"
-#include "systemclock.h"
-#include "taglist.h"
-#include "tagsetter.h"
-#include "task.h"
-#include "taskpool.h"
-#include "tunerchannel.h"
-#include "tuner.h"
-#include "tunernorm.h"
-#include "typefindfactory.h"
-#include "typefind.h"
-#include "urihandler.h"
-#include "value.h"
-#include "videoorientation.h"
-#include "videosink.h"
-#include "xml.h"
-#include "xoverlay.h"
-#include "adder.h"
-#include "alsamixer.h"
-#include "alsasink.h"
-#include "alsasrc.h"
-#include "audioconvert.h"
-#include "audiorate.h"
-#include "audioresample.h"
-#include "audiotestsrc.h"
-#include "capsfilter.h"
-#include "cdparanoiasrc.h"
-#include "clockoverlay.h"
-#include "decodebin2.h"
-#include "decodebin.h"
 #include "fakesink.h"
 #include "fakesrc.h"
 #include "fdsink.h"
@@ -100,24 +58,58 @@
 #include "ffmpegcolorspace.h"
 #include "filesink.h"
 #include "filesrc.h"
+#include "filter.h"
+#include "format.h"
+#include "funnel.h"
 #include "gdpdepay.h"
 #include "gdppay.h"
+#include "ghostpad.h"
 #include "giosink.h"
 #include "giosrc.h"
 #include "giostreamsink.h"
 #include "giostreamsrc.h"
 #include "identity.h"
+#include "index.h"
+#include "indexfactory.h"
 #include "inputselector.h"
+#include "interface.h"
+#include "iterator.h"
+#include "message.h"
+#include "mixer.h"
+#include "mixeroptions.h"
+#include "mixertrack.h"
 #include "multifdsink.h"
 #include "multiqueue.h"
+#include "navigation.h"
+#include "object.h"
 #include "oggdemux.h"
 #include "oggmux.h"
 #include "outputselector.h"
-#include "playbin2.h"
+#include "pad.h"
+#include "padtemplate.h"
+#include "parse.h"
+#include "pipeline.h"
 #include "playbin.h"
+#include "playbin2.h"
+#include "plugin.h"
+#include "pluginfeature.h"
+#include "preset.h"
+#include "propertyprobe.h"
+#include "pushsrc.h"
+#include "query.h"
 #include "queue.h"
 #include "queue2.h"
+#include "registry.h"
+#include "ringbuffer.h"
+#include "segment.h"
+#include "streamvolume.h"
+#include "structure.h"
 #include "subtitleoverlay.h"
+#include "systemclock.h"
+#include "taglist.h"
+#include "tagsetter.h"
+#include "task.h"
+#include "taskpool.h"
 #include "tcpclientsink.h"
 #include "tcpclientsrc.h"
 #include "tcpserversink.h"
@@ -129,11 +121,20 @@
 #include "theoraenc.h"
 #include "theoraparse.h"
 #include "timeoverlay.h"
+#include "tuner.h"
+#include "tunerchannel.h"
+#include "tunernorm.h"
+#include "typefind.h"
 #include "typefindelement.h"
+#include "typefindfactory.h"
 #include "uridecodebin.h"
+#include "urihandler.h"
+#include "value.h"
 #include "valve.h"
+#include "videoorientation.h"
 #include "videorate.h"
 #include "videoscale.h"
+#include "videosink.h"
 #include "videotestsrc.h"
 #include "volume.h"
 #include "vorbisdec.h"
@@ -141,6 +142,8 @@
 #include "vorbisparse.h"
 #include "vorbistag.h"
 #include "ximagesink.h"
+#include "xml.h"
+#include "xoverlay.h"
 #include "xvimagesink.h"
 
 extern "C"
@@ -175,6 +178,7 @@ GType gst_clock_overlay_get_type(void);
 GType gst_color_balance_channel_get_type(void);
 GType gst_decode_bin_get_type(void);
 GType gst_decode_bin2_get_type(void);
+GType gst_discoverer_get_type(void);
 GType gst_element_get_type(void);
 GType gst_element_factory_get_type(void);
 GType gst_fake_sink_get_type(void);
@@ -184,6 +188,7 @@ GType gst_fd_src_get_type(void);
 GType gst_ff_mpeg_csp_get_type(void);
 GType gst_file_sink_get_type(void);
 GType gst_file_src_get_type(void);
+GType gst_funnel_get_type(void);
 GType gst_gdp_depay_get_type(void);
 GType gst_gdp_pay_get_type(void);
 GType gst_ghost_pad_get_type(void);
@@ -289,6 +294,7 @@ namespace Gst {  class ClockOverlay_Class { public: static Glib::ObjectBase* wra
 namespace Gst {  class ColorBalanceChannel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class DecodeBin_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class DecodeBin2_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class Discoverer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class Element_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class ElementFactory_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class FakeSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -298,6 +304,7 @@ namespace Gst {  class FdSrc_Class { public: static Glib::ObjectBase* wrap_new(G
 namespace Gst {  class FfmpegColorSpace_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class FileSink_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class FileSrc_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gst {  class Funnel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class GDPDepay_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class GDPPay_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gst {  class GhostPad_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -403,6 +410,7 @@ void wrap_init()
   Glib::wrap_register(gst_color_balance_channel_get_type(), &Gst::ColorBalanceChannel_Class::wrap_new);
   Glib::wrap_register(gst_decode_bin_get_type(), &Gst::DecodeBin_Class::wrap_new);
   Glib::wrap_register(gst_decode_bin2_get_type(), &Gst::DecodeBin2_Class::wrap_new);
+  Glib::wrap_register(gst_discoverer_get_type(), &Gst::Discoverer_Class::wrap_new);
   Glib::wrap_register(gst_element_get_type(), &Gst::Element_Class::wrap_new);
   Glib::wrap_register(gst_element_factory_get_type(), &Gst::ElementFactory_Class::wrap_new);
   Glib::wrap_register(gst_fake_sink_get_type(), &Gst::FakeSink_Class::wrap_new);
@@ -412,6 +420,7 @@ void wrap_init()
   Glib::wrap_register(gst_ff_mpeg_csp_get_type(), &Gst::FfmpegColorSpace_Class::wrap_new);
   Glib::wrap_register(gst_file_sink_get_type(), &Gst::FileSink_Class::wrap_new);
   Glib::wrap_register(gst_file_src_get_type(), &Gst::FileSrc_Class::wrap_new);
+  Glib::wrap_register(gst_funnel_get_type(), &Gst::Funnel_Class::wrap_new);
   Glib::wrap_register(gst_gdp_depay_get_type(), &Gst::GDPDepay_Class::wrap_new);
   Glib::wrap_register(gst_gdp_pay_get_type(), &Gst::GDPPay_Class::wrap_new);
   Glib::wrap_register(gst_ghost_pad_get_type(), &Gst::GhostPad_Class::wrap_new);
@@ -505,6 +514,7 @@ void wrap_init()
   Gst::ColorBalanceChannel::get_type();
   Gst::DecodeBin::get_type();
   Gst::DecodeBin2::get_type();
+  Gst::Discoverer::get_type();
   Gst::Element::get_type();
   Gst::ElementFactory::get_type();
   Gst::FakeSink::get_type();
@@ -514,6 +524,7 @@ void wrap_init()
   Gst::FfmpegColorSpace::get_type();
   Gst::FileSink::get_type();
   Gst::FileSrc::get_type();
+  Gst::Funnel::get_type();
   Gst::GDPDepay::get_type();
   Gst::GDPPay::get_type();
   Gst::GhostPad::get_type();
